Created initial README.md

Change-Id: Ic799939d918b1b037ece1bc434a4e0abc5a39e97
Signed-off-by: Zane Shelley <zshelle@us.ibm.com>
diff --git a/src/chip_data/CHIP_DATA.md b/src/chip_data/CHIP_DATA.md
new file mode 100644
index 0000000..7775b48
--- /dev/null
+++ b/src/chip_data/CHIP_DATA.md
@@ -0,0 +1,4 @@
+Chip Data File definition
+=========================
+
+TBD
diff --git a/src/hei_user_interface.hpp b/src/hei_user_interface.hpp
index b7dd092..30e869d 100644
--- a/src/hei_user_interface.hpp
+++ b/src/hei_user_interface.hpp
@@ -1,10 +1,33 @@
 
 #pragma once
 
-// This header provides access to headers and macros defined by the user
-// application.
-#include <hei_trace.hpp>
+// The user application must define this header file with the following macros:
+//
+//   Tracing (inputs same as printf() from <cstdio>):
+//      HEI_INF( ... ) // Generic informational trace
+//      HEI_ERR( ... ) // Error path trace
+//
+//  Assertion (at a minimum should work like assert() from <cassert>):
+//      HEI_ASSERT( expression )
+//
+#include <hei_user_defines.hpp>
 
-// The rest of this header contains interfaces that the user application must
-// define.
+namespace libhei
+{
+
+/**
+ *  @brief Perform a hardware read operation.
+ */
+void deviceRead();
+
+#ifndef __HEI_READ_ONLY
+
+/**
+ *  @brief Perform a hardware write operation.
+ */
+void deviceWrite();
+
+#endif
+
+} // end namespace libhei
diff --git a/src/hei_isolator.cpp b/src/hei_isolator.cpp
index ff58877..fda761f 100644
--- a/src/hei_isolator.cpp
+++ b/src/hei_isolator.cpp
@@ -1,27 +1,27 @@
 
 #include "hei_isolator.hpp"
 
-namespace HEI
+namespace libhei
 {
 
 Isolator::Isolator()
 {
-    HEI_TRAC( "Isolator::Isolator()" );
+    HEI_INF( "Isolator::Isolator()" );
 }
 
 Isolator::~Isolator()
 {
-    HEI_TRAC( "Isolator::~Isolator()" );
+    HEI_INF( "Isolator::~Isolator()" );
 }
 
 void Isolator::initialize()
 {
-    HEI_TRAC( "Isolator::initialize()" );
+    HEI_INF( "Isolator::initialize()" );
 }
 
 void Isolator::isolate()
 {
-    HEI_TRAC( "Isolator::isolate()" );
+    HEI_INF( "Isolator::isolate()" );
 }
 
-} // end namespace HEI
+} // end namespace libhei
diff --git a/src/hei_isolator.hpp b/src/hei_isolator.hpp
index 09ed43e..483b260 100644
--- a/src/hei_isolator.hpp
+++ b/src/hei_isolator.hpp
@@ -3,7 +3,7 @@
 
 #include "hei_user_interface.hpp"
 
-namespace HEI
+namespace libhei
 {
 
 class Isolator
@@ -22,4 +22,4 @@
 
 }; // end class Isolator
 
-} // end namespace HEI
+} // end namespace libhei